function [ptr,gratio]=gratio_fun(MT,gdt,gts,ord)

% GRATIO_FUN        A quick script using linear regression to obtain the
% ratio, ptr, between 0 and 1 that can be best described by the original
% time-series hyperparameter with the remaining described by dynamic
% lengthscale hyperparameters, and the ratio of the
% lengthscale hyperparameters, gratio, with respect to the time-series
% hyperparameter.
%
%   [ptr,gratio] = GRATIO_FUN(MT,gdt,gts,ord)
%
% Inputs:
%       MT  = Input time-series explanatory variables
%       gdt = A list of values of lengthscale hyperparameters
%       gts = Adapted time-series lengthscale hyperparameter
%       ord = Order of reduction in the state-space dataset
%
% Outputs:
%   ptr     = Column vector of the ratio of the prediction that can be
%             described by the time-series lengthscale hyperparameter, and
%             the remaining described by dynamic lengthsccale
%             hyperparameters values.
%   gratio  = Column vector of the ratio where dynamic lengthscale
%             hyperparameter values are larger than the time-series 
%             hyperparameter.
%
%
% (C) Gaussian Process SSTS Toolbox 1.0
% (C) Copyright 2006-2007, Keith Neo <keith.neo@nuim.ie>
%                          http://www.hamilton.ie

ggdt=(gdt>gts).*gdt+(gdt<gts)*gts;
gratio=(ggdt-gts)/(max(ggdt)-gts);

ss_MT=getord_vec(ord,MT);
pord=length(ss_MT)-1;
tr=zeros(ord+1,pord);
for k=1:pord
    ay=gratio(k:k+1);
    ax=ss_MT(k:k+1);
    als=regress(ay,[ones(2,1) ax]);
    np=ord*k+k;
    bx=MT(np-ord:np);
    tr(:,k)=als(1)+als(2)*bx;
end
tr=reshape(tr,numel(tr),1);
ptr=[tr;gratio(pord+1)*ones(length(MT)-numel(tr),1)];
